#[non_exhaustive]pub struct AgentAccessConfigBuilder { /* private fields */ }Expand description
A builder for AgentAccessConfig.
Implementations
Sourceimpl AgentAccessConfigBuilder
impl AgentAccessConfigBuilder
Sourcepub fn settings(self, input: AgentAccessSetting) -> Self
pub fn settings(self, input: AgentAccessSetting) -> Self
Appends an item to settings.
To override the contents of this collection use set_settings.
The list of agent access settings that define permissions for each agent action. You must specify at least one setting.
Sourcepub fn set_settings(self, input: Option<Vec<AgentAccessSetting>>) -> Self
pub fn set_settings(self, input: Option<Vec<AgentAccessSetting>>) -> Self
The list of agent access settings that define permissions for each agent action. You must specify at least one setting.
Sourcepub fn get_settings(&self) -> &Option<Vec<AgentAccessSetting>>
pub fn get_settings(&self) -> &Option<Vec<AgentAccessSetting>>
The list of agent access settings that define permissions for each agent action. You must specify at least one setting.
Sourcepub fn s3_bucket_arn(self, input: impl Into<String>) -> Self
pub fn s3_bucket_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.
Sourcepub fn set_s3_bucket_arn(self, input: Option<String>) -> Self
pub fn set_s3_bucket_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.
Sourcepub fn get_s3_bucket_arn(&self) -> &Option<String>
pub fn get_s3_bucket_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored. Required when ScreenshotsUploadEnabled is true.
Sourcepub fn screenshots_upload_enabled(self, input: bool) -> Self
pub fn screenshots_upload_enabled(self, input: bool) -> Self
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
Sourcepub fn set_screenshots_upload_enabled(self, input: Option<bool>) -> Self
pub fn set_screenshots_upload_enabled(self, input: Option<bool>) -> Self
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
Sourcepub fn get_screenshots_upload_enabled(&self) -> &Option<bool>
pub fn get_screenshots_upload_enabled(&self) -> &Option<bool>
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
Sourcepub fn screen_resolution(self, input: ScreenResolution) -> Self
pub fn screen_resolution(self, input: ScreenResolution) -> Self
The screen resolution for the agent streaming environment.
This field is required.Sourcepub fn set_screen_resolution(self, input: Option<ScreenResolution>) -> Self
pub fn set_screen_resolution(self, input: Option<ScreenResolution>) -> Self
The screen resolution for the agent streaming environment.
Sourcepub fn get_screen_resolution(&self) -> &Option<ScreenResolution>
pub fn get_screen_resolution(&self) -> &Option<ScreenResolution>
The screen resolution for the agent streaming environment.
Sourcepub fn screen_image_format(self, input: ScreenImageFormat) -> Self
pub fn screen_image_format(self, input: ScreenImageFormat) -> Self
The image format for agent screen captures.
This field is required.Sourcepub fn set_screen_image_format(self, input: Option<ScreenImageFormat>) -> Self
pub fn set_screen_image_format(self, input: Option<ScreenImageFormat>) -> Self
The image format for agent screen captures.
Sourcepub fn get_screen_image_format(&self) -> &Option<ScreenImageFormat>
pub fn get_screen_image_format(&self) -> &Option<ScreenImageFormat>
The image format for agent screen captures.
Sourcepub fn build(self) -> AgentAccessConfig
pub fn build(self) -> AgentAccessConfig
Consumes the builder and constructs a AgentAccessConfig.