#[non_exhaustive]pub struct AgentAccessConfigForUpdate {
pub settings: Option<Vec<AgentAccessSetting>>,
pub s3_bucket_arn: Option<String>,
pub screenshots_upload_enabled: Option<bool>,
pub screen_resolution: Option<ScreenResolution>,
pub screen_image_format: Option<ScreenImageFormat>,
}Expand description
The configuration for updating agent access on a stack. This type supports partial updates, so you only need to specify the fields you want to change.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.settings: Option<Vec<AgentAccessSetting>>The list of agent access settings that define permissions for each agent action.
s3_bucket_arn: Option<String>The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored.
screenshots_upload_enabled: Option<bool>Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
screen_resolution: Option<ScreenResolution>The screen resolution for the agent streaming environment.
screen_image_format: Option<ScreenImageFormat>The image format for agent screen captures.
Implementations
Sourceimpl AgentAccessConfigForUpdate
impl AgentAccessConfigForUpdate
Sourcepub fn settings(&self) -> &[AgentAccessSetting]
pub fn settings(&self) -> &[AgentAccessSetting]
The list of agent access settings that define permissions for each agent action.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .settings.is_none().
Sourcepub fn s3_bucket_arn(&self) -> Option<&str>
pub fn s3_bucket_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Amazon S3 bucket where agent screenshots are stored.
Sourcepub fn screenshots_upload_enabled(&self) -> Option<bool>
pub fn screenshots_upload_enabled(&self) -> Option<bool>
Indicates whether screenshot uploads to Amazon S3 are enabled for agent sessions.
Sourcepub fn screen_resolution(&self) -> Option<&ScreenResolution>
pub fn screen_resolution(&self) -> Option<&ScreenResolution>
The screen resolution for the agent streaming environment.
Sourcepub fn screen_image_format(&self) -> Option<&ScreenImageFormat>
pub fn screen_image_format(&self) -> Option<&ScreenImageFormat>
The image format for agent screen captures.
Sourceimpl AgentAccessConfigForUpdate
impl AgentAccessConfigForUpdate
Sourcepub fn builder() -> AgentAccessConfigForUpdateBuilder
pub fn builder() -> AgentAccessConfigForUpdateBuilder
Creates a new builder-style object to manufacture AgentAccessConfigForUpdate.